@@ -74,4 +74,7 @@ def fasta_profile(
             df.to_excel(out_path, index=False)
     except Exception as e:
         typer.echo(f"Error writing output file: {e}")
-        raise typer.Abort()
\ No newline at end of file
+        raise typer.Abort()
+    
+if __name__ == "__main__":
+    info_app()
\ No newline at end of file
